@@ -643,12 +643,12 @@ class GAlearner:
 
             elif self.learner_preset == "intense":
                 parameters={
-                    "loss": ["hinge", "log"],
+                    "loss": ["log"],
                     "penalty": ["elasticnet"],
                     "power_t": [0.1, 0.2, 0.3, 0.4, 0.5],
                     "class_weight": ["balanced"],
-                    "n_iter_no_change": [8, 32],
-                    "alpha": [0.05, 0.01, 0.005, 0.001, 0.0001, 0.0005],
+                    "n_iter_no_change": [8],
+                    "alpha": [0.0005],
                     "l1_ratio": [0, 0.05, 0.25, 0.3, 0.6, 0.8, 0.95, 1]
                 }
 
